@@ -36,7 +36,9 @@ pub(crate) enum Symbol {
 	ShiftLeft,
 	ShiftRight,
 	Semicolon,
-	Equals, // used for assignment
+	Equals,       // used for assignment
+	DoubleEquals, // used for equality
+	NotEquals,
 	Combination,
 	Permutation,
 }
@@ -65,6 +67,8 @@ impl fmt::Display for Symbol {
 			Self::ShiftRight => ">>",
 			Self::Semicolon => ";",
 			Self::Equals => "=",
+			Self::DoubleEquals => "==",
+			Self::NotEquals => "!=",
 			Self::Combination => "nCr",
 			Self::Permutation => "nPr",
 		};
@@ -505,7 +509,13 @@ fn parse_symbol(ch: char, input: &mut &str) -> FResult<Token> {
 		'(' => Symbol::OpenParens,
 		')' => Symbol::CloseParens,
 		'+' => Symbol::Add,
-		'!' => Symbol::Factorial,
+		'!' => {
+			if test_next('=') {
+				Symbol::NotEquals
+			} else {
+				Symbol::Factorial
+			}
+		}
 		// unicode minus sign
 		'-' | '\u{2212}' => Symbol::Sub,
 		'*' | '\u{d7}' | '\u{2715}' => {
@@ -523,6 +533,8 @@ fn parse_symbol(ch: char, input: &mut &str) -> FResult<Token> {
 		'=' => {
 			if test_next('>') {
 				Symbol::Fn
+			} else if test_next('=') {
+				Symbol::DoubleEquals
 			} else {
 				Symbol::Equals
 			}
