@@ -2,7 +2,8 @@ use std::{fmt, io};
 
 use crate::{
 	error::FendError,
-	serialize::{deserialize_u8, deserialize_usize, serialize_u8, serialize_usize},
+	result::FResult,
+	serialize::{Deserialize, Serialize},
 };
 
 #[derive(PartialEq, Eq, Clone, Copy, Default)]
@@ -57,33 +58,33 @@ impl fmt::Debug for FormattingStyle {
 }
 
 impl FormattingStyle {
-	pub(crate) fn serialize(&self, write: &mut impl io::Write) -> Result<(), FendError> {
+	pub(crate) fn serialize(&self, write: &mut impl io::Write) -> FResult<()> {
 		match self {
-			Self::ImproperFraction => serialize_u8(1, write)?,
-			Self::MixedFraction => serialize_u8(2, write)?,
-			Self::ExactFloat => serialize_u8(3, write)?,
-			Self::Exact => serialize_u8(4, write)?,
+			Self::ImproperFraction => 1u8.serialize(write)?,
+			Self::MixedFraction => 2u8.serialize(write)?,
+			Self::ExactFloat => 3u8.serialize(write)?,
+			Self::Exact => 4u8.serialize(write)?,
 			Self::DecimalPlaces(d) => {
-				serialize_u8(5, write)?;
-				serialize_usize(*d, write)?;
+				5u8.serialize(write)?;
+				d.serialize(write)?;
 			}
 			Self::SignificantFigures(s) => {
-				serialize_u8(6, write)?;
-				serialize_usize(*s, write)?;
+				6u8.serialize(write)?;
+				s.serialize(write)?;
 			}
-			Self::Auto => serialize_u8(7, write)?,
+			Self::Auto => 7u8.serialize(write)?,
 		}
 		Ok(())
 	}
 
-	pub(crate) fn deserialize(read: &mut impl io::Read) -> Result<Self, FendError> {
-		Ok(match deserialize_u8(read)? {
+	pub(crate) fn deserialize(read: &mut impl io::Read) -> FResult<Self> {
+		Ok(match u8::deserialize(read)? {
 			1 => Self::ImproperFraction,
 			2 => Self::MixedFraction,
 			3 => Self::ExactFloat,
 			4 => Self::Exact,
-			5 => Self::DecimalPlaces(deserialize_usize(read)?),
-			6 => Self::SignificantFigures(deserialize_usize(read)?),
+			5 => Self::DecimalPlaces(usize::deserialize(read)?),
+			6 => Self::SignificantFigures(usize::deserialize(read)?),
 			7 => Self::Auto,
 			_ => return Err(FendError::DeserializationError),
 		})
